==> openshift-model-monitoring-5.1.2-sources.jar: annotations/io/fabric8/openshift/api/model/monitoring/v1/PrometheusStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class PrometheusStatusFluentImpl<A extends PrometheusStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PrometheusStatusFluent<A> {

    private Integer availableReplicas;
    private Boolean paused;
    private Integer replicas;
    private Integer unavailableReplicas;
    private Integer updatedReplicas;

    public PrometheusStatusFluentImpl() {
    }

    public PrometheusStatusFluentImpl(PrometheusStatus instance) {
        this.withAvailableReplicas(instance.getAvailableReplicas()); 
        this.withPaused(instance.getPaused()); 
        this.withReplicas(instance.getReplicas()); 
        this.withUnavailableReplicas(instance.getUnavailableReplicas()); 
        this.withUpdatedReplicas(instance.getUpdatedReplicas()); 
    }

    public Integer getAvailableReplicas() {
        return this.availableReplicas;
    }

    public A withAvailableReplicas(Integer availableReplicas) {
        this.availableReplicas=availableReplicas; return (A) this;
    }

    public Boolean hasAvailableReplicas() {
        return this.availableReplicas != null;
    }

    public A withNewAvailableReplicas(String arg1) {
        return (A)withAvailableReplicas(new Integer(arg1));
    }

    public A withNewAvailableReplicas(int arg1) {
        return (A)withAvailableReplicas(new Integer(arg1));
    }

    public Boolean isPaused() {
        return this.paused;
    }

    public A withPaused(Boolean paused) {
        this.paused=paused; return (A) this;
    }

    public Boolean hasPaused() {
        return this.paused != null;
    }

    public A withNewPaused(String arg1) {
        return (A)withPaused(new Boolean(arg1));
    }

    public A withNewPaused(boolean arg1) {
        return (A)withPaused(new Boolean(arg1));
    }

    public Integer getReplicas() {
        return this.replicas;
    }

    public A withReplicas(Integer replicas) {
        this.replicas=replicas; return (A) this;
    }

    public Boolean hasReplicas() {
        return this.replicas != null;
    }

    public A withNewReplicas(String arg1) {
        return (A)withReplicas(new Integer(arg1));
    }

    public A withNewReplicas(int arg1) {
        return (A)withReplicas(new Integer(arg1));
    }

    public Integer getUnavailableReplicas() {
        return this.unavailableReplicas;
    }

    public A withUnavailableReplicas(Integer unavailableReplicas) {
        this.unavailableReplicas=unavailableReplicas; return (A) this;
    }

    public Boolean hasUnavailableReplicas() {
        return this.unavailableReplicas != null;
    }

    public A withNewUnavailableReplicas(String arg1) {
        return (A)withUnavailableReplicas(new Integer(arg1));
    }

    public A withNewUnavailableReplicas(int arg1) {
        return (A)withUnavailableReplicas(new Integer(arg1));
    }

    public Integer getUpdatedReplicas() {
        return this.updatedReplicas;
    }

    public A withUpdatedReplicas(Integer updatedReplicas) {
        this.updatedReplicas=updatedReplicas; return (A) this;
    }

    public Boolean hasUpdatedReplicas() {
        return this.updatedReplicas != null;
    }

    public A withNewUpdatedReplicas(String arg1) {
        return (A)withUpdatedReplicas(new Integer(arg1));
    }

    public A withNewUpdatedReplicas(int arg1) {
        return (A)withUpdatedReplicas(new Integer(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        PrometheusStatusFluentImpl that = (PrometheusStatusFluentImpl) o;
        if (availableReplicas != null ? !availableReplicas.equals(that.availableReplicas) :that.availableReplicas != null) return false;
        if (paused != null ? !paused.equals(that.paused) :that.paused != null) return false;
        if (replicas != null ? !replicas.equals(that.replicas) :that.replicas != null) return false;
        if (unavailableReplicas != null ? !unavailableReplicas.equals(that.unavailableReplicas) :that.unavailableReplicas != null) return false;
        if (updatedReplicas != null ? !updatedReplicas.equals(that.updatedReplicas) :that.updatedReplicas != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(availableReplicas,  paused,  replicas,  unavailableReplicas,  updatedReplicas,  super.hashCode());
    }

}

==> openshift-model-monitoring-5.3.0-sources.jar: annotations/io/fabric8/openshift/api/model/monitoring/v1/PrometheusStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class PrometheusStatusFluentImpl<A extends PrometheusStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PrometheusStatusFluent<A> {

    private Integer availableReplicas;
    private Boolean paused;
    private Integer replicas;
    private Integer unavailableReplicas;
    private Integer updatedReplicas;

    public PrometheusStatusFluentImpl() {
    }

    public PrometheusStatusFluentImpl(PrometheusStatus instance) {
        this.withAvailableReplicas(instance.getAvailableReplicas()); 
        this.withPaused(instance.getPaused()); 
        this.withReplicas(instance.getReplicas()); 
        this.withUnavailableReplicas(instance.getUnavailableReplicas()); 
        this.withUpdatedReplicas(instance.getUpdatedReplicas()); 
    }

    public Integer getAvailableReplicas() {
        return this.availableReplicas;
    }

    public A withAvailableReplicas(Integer availableReplicas) {
        this.availableReplicas=availableReplicas; return (A) this;
    }

    public Boolean hasAvailableReplicas() {
        return this.availableReplicas != null;
    }

    public A withNewAvailableReplicas(int arg1) {
        return (A)withAvailableReplicas(new Integer(arg1));
    }

    public Boolean getPaused() {
        return this.paused;
    }

    public A withPaused(Boolean paused) {
        this.paused=paused; return (A) this;
    }

    public Boolean hasPaused() {
        return this.paused != null;
    }

    public A withNewPaused(String arg1) {
        return (A)withPaused(new Boolean(arg1));
    }

    public A withNewPaused(boolean arg1) {
        return (A)withPaused(new Boolean(arg1));
    }

    public Integer getReplicas() {
        return this.replicas;
    }

    public A withReplicas(Integer replicas) {
        this.replicas=replicas; return (A) this;
    }

    public Boolean hasReplicas() {
        return this.replicas != null;
    }

    public A withNewReplicas(int arg1) {
        return (A)withReplicas(new Integer(arg1));
    }

    public Integer getUnavailableReplicas() {
        return this.unavailableReplicas;
    }

    public A withUnavailableReplicas(Integer unavailableReplicas) {
        this.unavailableReplicas=unavailableReplicas; return (A) this;
    }

    public Boolean hasUnavailableReplicas() {
        return this.unavailableReplicas != null;
    }

    public A withNewUnavailableReplicas(int arg1) {
        return (A)withUnavailableReplicas(new Integer(arg1));
    }

    public Integer getUpdatedReplicas() {
        return this.updatedReplicas;
    }

    public A withUpdatedReplicas(Integer updatedReplicas) {
        this.updatedReplicas=updatedReplicas; return (A) this;
    }

    public Boolean hasUpdatedReplicas() {
        return this.updatedReplicas != null;
    }

    public A withNewUpdatedReplicas(int arg1) {
        return (A)withUpdatedReplicas(new Integer(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        PrometheusStatusFluentImpl that = (PrometheusStatusFluentImpl) o;
        if (availableReplicas != null ? !availableReplicas.equals(that.availableReplicas) :that.availableReplicas != null) return false;
        if (paused != null ? !paused.equals(that.paused) :that.paused != null) return false;
        if (replicas != null ? !replicas.equals(that.replicas) :that.replicas != null) return false;
        if (unavailableReplicas != null ? !unavailableReplicas.equals(that.unavailableReplicas) :that.unavailableReplicas != null) return false;
        if (updatedReplicas != null ? !updatedReplicas.equals(that.updatedReplicas) :that.updatedReplicas != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(availableReplicas,  paused,  replicas,  unavailableReplicas,  updatedReplicas,  super.hashCode());
    }

}
